/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.agent.management.api.xml;

import org.ow2.jonas.agent.management.api.app.ApplicationStatus;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Application XML element
 * Represents an application
 * @author David Richard
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class App {

    /**
     * Application name
     */
    @XmlAttribute
    private String name;

    /**
     * Application status
     */
    @XmlAttribute
    private String status;

    @XmlAttribute
    private String type;

    @XmlAttribute
    private String href;


    public String getName() {
        return name;
    }

    public String getStatus() {
        return status;
    }

    public String getType() {
        return type;
    }

    public String getHref() {
        return href;
    }

    public void setName(String name) {
        this.name = name;
    }

    public synchronized void setStatus(ApplicationStatus status) {
        this.status = String.valueOf(status);
    }

    public void setType(String type) {
        this.type = type;
    }

    public void setHref(String href) {
        this.href = href;
    }

    /**
     * @return the {@link org.ow2.jonas.agent.management.api.app.ApplicationStatus} of the application
     */
    public ApplicationStatus getApplicationStatus() {
        if (this.status != null) {
            if (ApplicationStatus.DEPLOYING.toString().equals(status)) {
                return ApplicationStatus.DEPLOYING;
            } else if (ApplicationStatus.DEPLOYED.toString().equals(status)) {
                return ApplicationStatus.DEPLOYED;
            } else if (ApplicationStatus.UNDEPLOYING.toString().equals(status)) {
                return ApplicationStatus.UNDEPLOYING;
            } else if (ApplicationStatus.ERROR.toString().equals(status)) {
                return ApplicationStatus.ERROR;
            } else if (ApplicationStatus.NOT_DEPLOYED.toString().equals(status)) {
                return ApplicationStatus.NOT_DEPLOYED;
            }
        }
        return null;
    }
}
