/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.agent.management.api.xml;

import org.ow2.jonas.agent.management.api.server.JOnASStatus;
import org.ow2.jonas.report.generated.Report;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Server XML element
 * Represents a manage server
 * @author Jeremy Cazaux
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class Server {

    /**
     * Server name
     */
    @XmlAttribute
    private String name;

    /**
     * Server status
     */
    @XmlAttribute
    private String status;

    @XmlAttribute
    private String  type;

    @XmlAttribute
    private String href;

    /**
     * The Report
     */
    @XmlElement
    private Report report;

    /**
     * List of applications deployed on the server
     */
    @XmlElement
    private AppList appList;

    public String getName() {
        return name;
    }

    public String getStatus() {
        return status;
    }

    public String getType() {
        return type;
    }

    public String getHref() {
        return href;
    }

    public Report getReport() {
        return report;
    }

    public AppList getAppList() {
        return appList;
    }

    public void setName(String name) {
        this.name = name;
    }

    public synchronized void setStatus(JOnASStatus status) {
        this.status = String.valueOf(status);
    }

    public void setType(String type) {
        this.type = type;
    }

    public void setHref(String href) {
        this.href = href;
    }

    public void setReport(Report report) {
        this.report = report;
    }

    public void setAppList(AppList appList) {
        this.appList = appList;
    }

    /**
     * @return the {@link JOnASStatus} of the server
     */
    public JOnASStatus getJOnASStatus() {
        if (this.status != null) {
            if (JOnASStatus.CREATING.toString().equals(status)) {
                return JOnASStatus.CREATING;
            } else if (JOnASStatus.NOT_CREATED.toString().equals(status)) {
                return JOnASStatus.NOT_CREATED;
            } else if (JOnASStatus.STARTED.toString().equals(status)) {
                return JOnASStatus.STARTED;
            } else if (JOnASStatus.STARTING.toString().equals(status)) {
                return JOnASStatus.STARTING;
            } else if (JOnASStatus.STOPPED.toString().equals(status)) {
                return JOnASStatus.STOPPED;
            } else if (JOnASStatus.STOPPING.toString().equals(status)) {
                return JOnASStatus.STOPPING;
            }
        }
        return null;
    }
}
