/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.agent.management.api.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Task XML element
 * @author Jeremy Cazaux
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "task", propOrder = {
        "link", "owner"
})
public class Task {

    /**
     * Task id
     */
    @XmlAttribute
    private Long id;

    /**
     * Task status
     */
    @XmlAttribute
    private String status;

    /**
     *
     */
    @XmlAttribute
    private Date startTime;

    @XmlAttribute
    private Date endTime;

    @XmlAttribute
    private String operationName;

    @XmlElement
    private List<Link> link;

    @XmlElement
    private Owner owner;

    /**
     * Default constructor
     */
    public Task() {
        this.link = new ArrayList<Link>();
    }

    public Long getId() {
        return id;
    }

    public String getOperationName() {
        return operationName;
    }

    public Date getStartTime() {
        return startTime;
    }

    public String getStatus() {
        return status;
    }

    public List<Link> getLink() {
        return link;
    }

    public Owner getOwner() {
        return owner;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setId(final Long id) {
        this.id = id;
    }

    public void setStatus(final String status) {
        this.status = status;
    }

    public void setStartTime(final Date startTime) {
        this.startTime = startTime;
    }

    public void setOperationName(final String operationName) {
        this.operationName = operationName;
    }

    public void addLink(final Link link) {
        this.link.add(link);
    }

    public void setOwner(final Owner owner) {
        this.owner = owner;
    }

    public void setEndTime(final Date endTime) {
        this.endTime = endTime;
    }

    public void setLink(final List<Link> link) {
        this.link = link;
    }
}
